@@ -2,4 +2,4 @@
 from b3u.b3u import\
     cred, credentials,\
     conf, configuration,\
-    for_client, for_get
+    for_client, for_resource, for_get
